@@ -8,14 +8,16 @@ from __future__ import annotations
 import os
 from abc import ABC, abstractmethod
 from collections import deque
+from copy import deepcopy
 from dataclasses import InitVar, dataclass, field, fields
 from functools import lru_cache
-from typing import TYPE_CHECKING, Any, Deque, Iterator, Sequence, Set, Tuple
+from typing import TYPE_CHECKING, Any, Deque, Iterator, Set, Tuple
 
 import regex as re
 
 from cfnlint.context._mappings import Mappings
 from cfnlint.context.conditions._conditions import Conditions
+from cfnlint.context.parameters import ParameterSet
 from cfnlint.helpers import (
     BOOLEAN_STRINGS_TRUE,
     FUNCTIONS,
@@ -145,12 +147,12 @@ class Context:
     """
 
     # what regions we are processing
-    regions: Sequence[str] = field(
+    regions: list[str] = field(
         init=True, default_factory=lambda: list([REGION_PRIMARY])
     )
 
     # supported functions at this point in the template
-    functions: Sequence[str] = field(init=True, default_factory=list)
+    functions: list[str] = field(init=True, default_factory=list)
 
     path: Path = field(init=True, default_factory=Path)
 
@@ -166,7 +168,7 @@ class Context:
         init=True, default_factory=lambda: set(PSEUDOPARAMS)
     )
 
-    # Combiniation of storing any resolved ref
+    # Combination of storing any resolved ref
     # and adds in any Refs available from things like Fn::Sub
     ref_values: dict[str, Any] = field(init=True, default_factory=dict)
 
@@ -176,6 +178,10 @@ class Context:
     is_resolved_value: bool = field(init=True, default=False)
     resolve_pseudo_parameters: bool = field(init=True, default=True)
 
+    # Deployment parameters
+    parameter_sets: list[ParameterSet] | None = field(init=True, default_factory=list)
+    is_resolved_from_parameters: bool = field(init=True, default=False)
+
     def evolve(self, **kwargs) -> "Context":
         """
         Create a new context without merging together attributes
@@ -210,19 +216,6 @@ class Context:
             if pseudo_value is not None:
                 yield pseudo_value, self.evolve(ref_values={instance: pseudo_value})
             return
-        if instance in self.parameters:
-            for v, path in self.parameters[instance].ref_value(self):
-
-                # validate that ref is possible with path
-                # need to evaluate if Fn::If would be not true if value is
-                # what it is
-                yield v, self.evolve(
-                    path=self.path.evolve(
-                        value_path=deque(["Parameters", instance]) + path
-                    ),
-                    ref_values={instance: v},
-                )
-            return
 
         # Regionalized values second
         if instance in PSEUDOPARAMS and instance in self.pseudo_parameters:
@@ -238,6 +231,43 @@ class Context:
                     },
                 )
 
+        if instance in self.parameters:
+            # if parameter sets are configured we use those first
+            # we default to the parameter values if the parameter isn't in that set
+            if self.parameter_sets is not None and len(self.parameter_sets) > 0:
+                for parameter_set in self.parameter_sets:
+                    if instance in parameter_set.parameters:
+                        yield parameter_set.parameters[instance], self.evolve(
+                            ref_values=parameter_set.parameters,
+                            parameter_sets=None,
+                            is_resolved_from_parameters=True,
+                        )
+                    else:
+                        for v, path in self.parameters[instance].default_value():
+                            parameters = deepcopy(parameter_set.parameters)
+                            parameters.update({instance: v})
+                            yield v, self.evolve(
+                                path=self.path.evolve(
+                                    value_path=deque(["Parameters", instance]) + path
+                                ),
+                                ref_values=parameters,
+                                parameter_sets=None,
+                                is_resolved_from_parameters=True,
+                            )
+                return
+
+            for v, path in self.parameters[instance].ref_value(self):
+
+                # validate that ref is possible with path
+                # need to evaluate if Fn::If would be not true if value is
+                # what it is
+                yield v, self.evolve(
+                    path=self.path.evolve(
+                        value_path=deque(["Parameters", instance]) + path
+                    ),
+                    ref_values={instance: v},
+                )
+
     @property
     def refs(self):
         pseudo_params = list(self.pseudo_parameters)
@@ -371,6 +401,13 @@ class Parameter(_Ref):
     def ref(self, region: str = REGION_PRIMARY) -> dict[str, Any]:
         return {}
 
+    def default_value(self) -> Iterator[Tuple[str | list[str], deque]]:
+        if self.default is not None:
+            if isinstance(self.default, list):
+                yield [str(x) for x in self.default], deque(["Default"])
+            else:
+                yield str(self.default), deque(["Default"])
+
     def ref_value(self, context: Context) -> Iterator[Tuple[Any, deque]]:
         if self.allowed_values:
             for i, allowed_value in enumerate(self.allowed_values):
@@ -381,11 +418,7 @@ class Parameter(_Ref):
             # assume default is an allowed value so we skip it
             return
 
-        if self.default is not None:
-            if isinstance(self.default, list):
-                yield [str(x) for x in self.default], deque(["Default"])
-            else:
-                yield str(self.default), deque(["Default"])
+        yield from self.default_value()
 
         if self.min_value is not None:
             yield str(self.min_value), deque(["MinValue"])
@@ -513,7 +546,9 @@ def _init_transforms(transforms: Any) -> Transforms:
     return Transforms([])
 
 
-def create_context_for_template(cfn: Template) -> "Context":
+def create_context_for_template(
+    cfn: Template,
+) -> "Context":
     parameters = {}
     try:
         parameters = _init_parameters(cfn.template.get("Parameters", {}))
@@ -548,4 +583,6 @@ def create_context_for_template(cfn: Template) -> "Context":
         regions=cfn.regions,
         path=Path(),
         functions=["Fn::Transform"],
+        ref_values={},
+        parameter_sets=[],
     )
