@@ -409,6 +409,8 @@ types: list[str] = [
     "AWS::ImageBuilder::InfrastructureConfiguration",
     "AWS::ImageBuilder::LifecyclePolicy",
     "AWS::ImageBuilder::Workflow",
+    "AWS::InspectorV2::CisScanConfiguration",
+    "AWS::InspectorV2::Filter",
     "AWS::InternetMonitor::Monitor",
     "AWS::IoT::Certificate",
     "AWS::IoT::Policy",
@@ -504,6 +506,7 @@ types: list[str] = [
     "AWS::NetworkManager::CoreNetwork",
     "AWS::NetworkManager::CustomerGatewayAssociation",
     "AWS::NetworkManager::Device",
+    "AWS::NetworkManager::DirectConnectGatewayAttachment",
     "AWS::NetworkManager::GlobalNetwork",
     "AWS::NetworkManager::Link",
     "AWS::NetworkManager::LinkAssociation",
@@ -597,8 +600,11 @@ types: list[str] = [
     "AWS::S3::AccessPoint",
     "AWS::S3::Bucket",
     "AWS::S3::BucketPolicy",
+    "AWS::S3::MultiRegionAccessPoint",
+    "AWS::S3::MultiRegionAccessPointPolicy",
     "AWS::S3ObjectLambda::AccessPoint",
     "AWS::S3ObjectLambda::AccessPointPolicy",
+    "AWS::S3Tables::Namespace",
     "AWS::S3Tables::TableBucket",
     "AWS::S3Tables::TableBucketPolicy",
     "AWS::SDB::Domain",
@@ -837,7 +843,6 @@ cached: list[str] = [
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
     "aws-cloudfront-connectiongroup.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
-    "aws-cloudfront-distribution.json",
     "aws-cloudfront-distributiontenant.json",
     "aws-cloudfront-function.json",
     "aws-cloudfront-keygroup.json",
@@ -921,6 +926,7 @@ cached: list[str] = [
     "aws-ec2-customergateway.json",
     "aws-ec2-dhcpoptions.json",
     "aws-ec2-ec2fleet.json",
+    "aws-ec2-egressonlyinternetgateway.json",
     "aws-ec2-eip.json",
     "aws-ec2-eipassociation.json",
     "aws-ec2-flowlog.json",
@@ -957,8 +963,8 @@ cached: list[str] = [
     "aws-ec2-subnetcidrblock.json",
     "aws-ec2-subnetnetworkaclassociation.json",
     "aws-ec2-subnetroutetableassociation.json",
+    "aws-ec2-trafficmirrorfilter.json",
     "aws-ec2-trafficmirrorfilterrule.json",
-    "aws-ec2-trafficmirrortarget.json",
     "aws-ec2-transitgateway.json",
     "aws-ec2-transitgatewayattachment.json",
     "aws-ec2-transitgatewayconnect.json",
@@ -1000,6 +1006,7 @@ cached: list[str] = [
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
     "aws-ecs-service.json",
+    "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
     "aws-efs-filesystem.json",
@@ -1094,12 +1101,13 @@ cached: list[str] = [
     "aws-imagebuilder-component.json",
     "aws-imagebuilder-containerrecipe.json",
     "aws-imagebuilder-distributionconfiguration.json",
-    "aws-imagebuilder-image.json",
     "aws-imagebuilder-imagepipeline.json",
     "aws-imagebuilder-imagerecipe.json",
     "aws-imagebuilder-infrastructureconfiguration.json",
     "aws-imagebuilder-lifecyclepolicy.json",
     "aws-imagebuilder-workflow.json",
+    "aws-inspectorv2-cisscanconfiguration.json",
+    "aws-inspectorv2-filter.json",
     "aws-internetmonitor-monitor.json",
     "aws-iot-thingprincipalattachment.json",
     "aws-kinesis-resourcepolicy.json",
@@ -1107,6 +1115,7 @@ cached: list[str] = [
     "aws-kinesisanalyticsv2-application.json",
     "aws-kinesisfirehose-deliverystream.json",
     "aws-kms-alias.json",
+    "aws-kms-key.json",
     "aws-kms-replicakey.json",
     "aws-lakeformation-datacellsfilter.json",
     "aws-lakeformation-datalakesettings.json",
@@ -1173,6 +1182,7 @@ cached: list[str] = [
     "aws-mwaa-environment.json",
     "aws-neptune-dbcluster.json",
     "aws-neptune-dbclusterparametergroup.json",
+    "aws-neptune-dbinstance.json",
     "aws-neptune-dbparametergroup.json",
     "aws-neptune-dbsubnetgroup.json",
     "aws-neptune-eventsubscription.json",
@@ -1187,6 +1197,7 @@ cached: list[str] = [
     "aws-networkmanager-corenetwork.json",
     "aws-networkmanager-customergatewayassociation.json",
     "aws-networkmanager-device.json",
+    "aws-networkmanager-directconnectgatewayattachment.json",
     "aws-networkmanager-globalnetwork.json",
     "aws-networkmanager-link.json",
     "aws-networkmanager-linkassociation.json",
@@ -1262,13 +1273,10 @@ cached: list[str] = [
     "aws-route53resolver-firewalldomainlist.json",
     "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
-    "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverdnssecconfig.json",
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
-    "aws-route53resolver-resolverrule.json",
-    "aws-route53resolver-resolverruleassociation.json",
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
@@ -1276,8 +1284,11 @@ cached: list[str] = [
     "aws-s3-accesspoint.json",
     "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
+    "aws-s3-multiregionaccesspoint.json",
+    "aws-s3-multiregionaccesspointpolicy.json",
     "aws-s3objectlambda-accesspoint.json",
     "aws-s3objectlambda-accesspointpolicy.json",
+    "aws-s3tables-namespace.json",
     "aws-s3tables-tablebucket.json",
     "aws-s3tables-tablebucketpolicy.json",
     "aws-sagemaker-cluster.json",
