@@ -178,6 +178,10 @@ types: list[str] = [
     "AWS::DynamoDB::GlobalTable",
     "AWS::DynamoDB::Table",
     "AWS::EC2::CapacityReservation",
+    "AWS::EC2::ClientVpnAuthorizationRule",
+    "AWS::EC2::ClientVpnEndpoint",
+    "AWS::EC2::ClientVpnRoute",
+    "AWS::EC2::ClientVpnTargetNetworkAssociation",
     "AWS::EC2::CustomerGateway",
     "AWS::EC2::DHCPOptions",
     "AWS::EC2::EC2Fleet",
@@ -580,6 +584,10 @@ types: list[str] = [
     "AWS::ServiceDiscovery::PrivateDnsNamespace",
     "AWS::ServiceDiscovery::PublicDnsNamespace",
     "AWS::ServiceDiscovery::Service",
+    "AWS::Shield::DRTAccess",
+    "AWS::Shield::ProactiveEngagement",
+    "AWS::Shield::Protection",
+    "AWS::Shield::ProtectionGroup",
     "AWS::StepFunctions::Activity",
     "AWS::StepFunctions::StateMachine",
     "AWS::StepFunctions::StateMachineAlias",
@@ -775,6 +783,9 @@ cached: list[str] = [
     "aws-dynamodb-globaltable.json",
     "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
+    "aws-ec2-clientvpnendpoint.json",
+    "aws-ec2-clientvpnroute.json",
+    "aws-ec2-clientvpntargetnetworkassociation.json",
     "aws-ec2-customergateway.json",
     "aws-ec2-dhcpoptions.json",
     "aws-ec2-ec2fleet.json",
@@ -815,7 +826,7 @@ cached: list[str] = [
     "aws-ec2-subnetnetworkaclassociation.json",
     "aws-ec2-subnetroutetableassociation.json",
     "aws-ec2-trafficmirrorfilter.json",
-    "aws-ec2-trafficmirrortarget.json",
+    "aws-ec2-trafficmirrorfilterrule.json",
     "aws-ec2-transitgateway.json",
     "aws-ec2-transitgatewayattachment.json",
     "aws-ec2-transitgatewayconnect.json",
@@ -943,7 +954,6 @@ cached: list[str] = [
     "aws-imagebuilder-component.json",
     "aws-imagebuilder-containerrecipe.json",
     "aws-imagebuilder-distributionconfiguration.json",
-    "aws-imagebuilder-image.json",
     "aws-imagebuilder-imagepipeline.json",
     "aws-imagebuilder-imagerecipe.json",
     "aws-imagebuilder-infrastructureconfiguration.json",
@@ -951,6 +961,7 @@ cached: list[str] = [
     "aws-iot-thingprincipalattachment.json",
     "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
+    "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalyticsv2-application.json",
     "aws-kinesisfirehose-deliverystream.json",
     "aws-kms-alias.json",
@@ -990,6 +1001,7 @@ cached: list[str] = [
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
     "aws-logs-subscriptionfilter.json",
+    "aws-logs-transformer.json",
     "aws-msk-batchscramsecret.json",
     "aws-msk-cluster.json",
     "aws-msk-clusterpolicy.json",
@@ -1124,6 +1136,10 @@ cached: list[str] = [
     "aws-servicediscovery-privatednsnamespace.json",
     "aws-servicediscovery-publicdnsnamespace.json",
     "aws-servicediscovery-service.json",
+    "aws-shield-drtaccess.json",
+    "aws-shield-proactiveengagement.json",
+    "aws-shield-protection.json",
+    "aws-shield-protectiongroup.json",
     "aws-sns-subscription.json",
     "aws-sns-topic.json",
     "aws-sns-topicinlinepolicy.json",
