@@ -399,6 +399,11 @@ types: list[str] = [
     "AWS::EC2::PlacementGroup",
     "AWS::EC2::PrefixList",
     "AWS::EC2::Route",
+    "AWS::EC2::RouteServer",
+    "AWS::EC2::RouteServerAssociation",
+    "AWS::EC2::RouteServerEndpoint",
+    "AWS::EC2::RouteServerPeer",
+    "AWS::EC2::RouteServerPropagation",
     "AWS::EC2::RouteTable",
     "AWS::EC2::SecurityGroup",
     "AWS::EC2::SecurityGroupEgress",
@@ -639,6 +644,9 @@ types: list[str] = [
     "AWS::IoTEvents::DetectorModel",
     "AWS::IoTEvents::Input",
     "AWS::IoTFleetHub::Application",
+    "AWS::IoTManagedIntegrations::CredentialLocker",
+    "AWS::IoTManagedIntegrations::ManagedThing",
+    "AWS::IoTManagedIntegrations::ProvisioningProfile",
     "AWS::IoTSiteWise::AccessPolicy",
     "AWS::IoTSiteWise::Asset",
     "AWS::IoTSiteWise::AssetModel",
@@ -965,6 +973,7 @@ types: list[str] = [
     "AWS::S3Outposts::BucketPolicy",
     "AWS::S3Outposts::Endpoint",
     "AWS::S3Tables::Namespace",
+    "AWS::S3Tables::Table",
     "AWS::S3Tables::TableBucket",
     "AWS::S3Tables::TableBucketPolicy",
     "AWS::SDB::Domain",
@@ -1336,7 +1345,6 @@ cached: list[str] = [
     "aws-bedrock-flow.json",
     "aws-bedrock-flowalias.json",
     "aws-bedrock-flowversion.json",
-    "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
     "aws-bedrock-knowledgebase.json",
     "aws-bedrock-prompt.json",
@@ -1344,6 +1352,7 @@ cached: list[str] = [
     "aws-budgets-budget.json",
     "aws-budgets-budgetsaction.json",
     "aws-cassandra-keyspace.json",
+    "aws-cassandra-table.json",
     "aws-cassandra-type.json",
     "aws-ce-anomalymonitor.json",
     "aws-ce-anomalysubscription.json",
@@ -1588,6 +1597,11 @@ cached: list[str] = [
     "aws-ec2-placementgroup.json",
     "aws-ec2-prefixlist.json",
     "aws-ec2-route.json",
+    "aws-ec2-routeserver.json",
+    "aws-ec2-routeserverassociation.json",
+    "aws-ec2-routeserverendpoint.json",
+    "aws-ec2-routeserverpeer.json",
+    "aws-ec2-routeserverpropagation.json",
     "aws-ec2-routetable.json",
     "aws-ec2-securitygroup.json",
     "aws-ec2-securitygroupegress.json",
@@ -1600,8 +1614,8 @@ cached: list[str] = [
     "aws-ec2-subnetnetworkaclassociation.json",
     "aws-ec2-subnetroutetableassociation.json",
     "aws-ec2-trafficmirrorfilter.json",
+    "aws-ec2-trafficmirrorfilterrule.json",
     "aws-ec2-trafficmirrorsession.json",
-    "aws-ec2-trafficmirrortarget.json",
     "aws-ec2-transitgateway.json",
     "aws-ec2-transitgatewayattachment.json",
     "aws-ec2-transitgatewayconnect.json",
@@ -1691,6 +1705,7 @@ cached: list[str] = [
     "aws-emr-studiosessionmapping.json",
     "aws-emr-walworkspace.json",
     "aws-emrcontainers-virtualcluster.json",
+    "aws-emrserverless-application.json",
     "aws-entityresolution-idmappingworkflow.json",
     "aws-entityresolution-idnamespace.json",
     "aws-entityresolution-matchingworkflow.json",
@@ -2085,6 +2100,7 @@ cached: list[str] = [
     "aws-redshift-integration.json",
     "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
+    "aws-redshiftserverless-snapshot.json",
     "aws-redshiftserverless-workgroup.json",
     "aws-refactorspaces-application.json",
     "aws-refactorspaces-environment.json",
@@ -2137,6 +2153,7 @@ cached: list[str] = [
     "aws-s3outposts-bucketpolicy.json",
     "aws-s3outposts-endpoint.json",
     "aws-s3tables-namespace.json",
+    "aws-s3tables-table.json",
     "aws-s3tables-tablebucket.json",
     "aws-s3tables-tablebucketpolicy.json",
     "aws-sagemaker-app.json",
