@@ -869,6 +869,7 @@ types: list[str] = [
     "AWS::S3Outposts::BucketPolicy",
     "AWS::S3Outposts::Endpoint",
     "AWS::S3Tables::Namespace",
+    "AWS::S3Tables::Table",
     "AWS::S3Tables::TableBucket",
     "AWS::S3Tables::TableBucketPolicy",
     "AWS::SDB::Domain",
@@ -1212,7 +1213,6 @@ cached: list[str] = [
     "aws-bedrock-flow.json",
     "aws-bedrock-flowalias.json",
     "aws-bedrock-flowversion.json",
-    "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
     "aws-bedrock-knowledgebase.json",
     "aws-bedrock-prompt.json",
@@ -1443,7 +1443,6 @@ cached: list[str] = [
     "aws-ec2-trafficmirrorfilter.json",
     "aws-ec2-trafficmirrorfilterrule.json",
     "aws-ec2-trafficmirrorsession.json",
-    "aws-ec2-trafficmirrortarget.json",
     "aws-ec2-transitgateway.json",
     "aws-ec2-transitgatewayattachment.json",
     "aws-ec2-transitgatewayconnect.json",
@@ -1867,6 +1866,7 @@ cached: list[str] = [
     "aws-redshift-integration.json",
     "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
+    "aws-redshiftserverless-snapshot.json",
     "aws-redshiftserverless-workgroup.json",
     "aws-refactorspaces-application.json",
     "aws-refactorspaces-environment.json",
@@ -1918,6 +1918,7 @@ cached: list[str] = [
     "aws-s3outposts-bucketpolicy.json",
     "aws-s3outposts-endpoint.json",
     "aws-s3tables-namespace.json",
+    "aws-s3tables-table.json",
     "aws-s3tables-tablebucket.json",
     "aws-s3tables-tablebucketpolicy.json",
     "aws-sagemaker-app.json",
